<?php
$lang['abbr_length'] = 'L';
$lang['abbr_width'] = 'W';
$lang['abbr_height'] = 'H';
$lang['add'] = 'Lis&auml;&auml;';
$lang['addcategory'] = 'Lis&auml;&auml; kategoria';
$lang['addfielddef'] = 'Lis&auml;&auml; kentt&auml;';
$lang['adjustable'] = 'S&auml;&auml;dett&auml;v&auml;';
$lang['addproduct'] = 'Lis&auml;&auml; tuote';
$lang['add_attrib_set'] = 'Lis&auml;&auml; attribuutti';
$lang['add_category_field'] = 'Liit&auml; kentt&auml; kategoriaan: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'Lis&auml;&auml; hierarkia';
$lang['add_option'] = 'Lis&auml;&auml; attribuutti optio';
$lang['admin_only'] = 'N&auml;kyvyys pelk&auml;st&auml;&auml;n admineille t&auml;h&auml;n attribuuttiin?';
$lang['advanced'] = 'Kehittynyt';
$lang['align_ul'] = 'Yl&ouml;s vasemmalle';
$lang['align_uc'] = 'Yl&ouml;s keskelle';
$lang['align_ur'] = 'Yl&ouml;s oikealle';
$lang['align_ml'] = 'Keskelle vasemmalle';
$lang['align_mc'] = 'Keskelle';
$lang['align_mr'] = 'Keskelle oikealle';
$lang['align_ll'] = 'Alas vasemmalle';
$lang['align_lc'] = 'Alas keskelle';
$lang['align_lr'] = 'Alas oikealle';
$lang['all'] = 'Kaikki';
$lang['allcategories'] = 'Kaikki kategoriat';
$lang['any'] = 'Mik&auml; tahansa';
$lang['areyousure'] = 'Oletko varma?';
$lang['areyousure_deleteproduct'] = 'Oletko varma, ett&auml; haluat poistaa t&auml;m&auml;n tuotteen ja sen tiedot?';
$lang['ascending'] = 'Nouseva';
$lang['attribute_name'] = 'Attribuutin nimi';
$lang['automatic'] = 'Automaattinen';
$lang['btn_setecomhandlers'] = 'Aseta verkkokaupan tapahtumak&auml;sittelij&auml;t';
$lang['byhierarchytemplates'] = 'Hierarkia raporttipohjat';
$lang['byhierarchytemplate_addedit'] = 'Lis&auml;&auml;/muokkaa Hierarkia raporttipohjaa';
$lang['cancel'] = 'Peruuta';
$lang['categories'] = 'Kategoriat';
$lang['category'] = 'Kategoria';
$lang['categoryexists'] = 'T&auml;m&auml;n niminen kategoria on jo luotu';
$lang['categorylisttemplates'] = 'Kategorialista pohjat';
$lang['categorylisttemplate_addedit'] = 'Lis&auml;&auml;/muokkaa kategorialista pohjaa';
$lang['centimeters'] = 'Senttimetrit';
$lang['checkbox'] = 'Valintalaatikko';
$lang['confirm_copyattributes'] = 'Kaikki asetetut attribuutit t&auml;lle tuotteelle poistetaan. Oletko varma ett&auml; haluat jatkaa?';
$lang['confirm_delete_hierarchy_node'] = 'Oletko varma, ett&auml; haluat poistaa t&auml;m&auml;n noden? Kaikki tuotteet, jotka k&auml;ytt&auml;v&auml;t t&auml;t&auml; nodea asetetaan tilaan &quot;ei hierarkiaa&quot;.';
$lang['confirm_import'] = 'Oletko varma, ett&auml; haluat tehd&auml; t&auml;m&auml;n?\n\nV&auml;&auml;r&auml;t asetukset tai virheellinen config-tiedosto voi pysyv&auml;sti korruptoida toimivan systeemin';
$lang['copy'] = 'Kopioi';
$lang['copy_product'] = 'Kopioi t&auml;m&auml; tuote';
$lang['copy_attrib_sets'] = 'Kopioi attribuutin asetukset';
$lang['copy_category'] = 'Kopioi';
$lang['createddate'] = 'Luontip&auml;iv&auml;';
$lang['current_value'] = 'Nykyinen arvo';
$lang['data'] = 'Tieto';
$lang['default'] = 'Oletus';
$lang['defaulttemplates'] = 'Oletuspohjat';
$lang['default_template_notice'] = '<strong>Huom:</strong> N&auml;iden tekstikenttien sis&auml;ll&ouml;ill&auml; m&auml;&auml;ritet&auml;&auml;n oletussis&auml;lt&ouml; pohjille, jossa luot uuden pohjan klikkaamalla &amp;quot;Lis&auml;&auml; pohja&amp;quot;. T&auml;nne tehdyt muutokset eiv&auml;t vaikuta suoraan sivuilla n&auml;kyv&auml;&auml;n sis&auml;lt&ouml;&ouml;n (vain oletuspohjiin).';
$lang['delete'] = 'Poista';
$lang['delete_attribset'] = 'Poista attribuutti';
$lang['delete_hierarchy_item'] = 'Poista hierarkia nimike';
$lang['descending'] = 'Laskeva';
$lang['description'] = 'Kuvaus';
$lang['destination'] = 'Kohde';
$lang['details'] = 'Tiedot';
$lang['detailtemplates'] = 'Yksityiskohtainen pohjat';
$lang['detailtemplate_addedit'] = 'Lis&auml;&auml;/muokkaa yksityiskohtaista pohjaa';
$lang['dimensions'] = 'Mitat';
$lang['disabled'] = 'Aktivoitu';
$lang['down'] = 'Siirr&auml; alas';
$lang['draft'] = 'Luonnos';
$lang['dropdown'] = 'Pudotusvalikko';
$lang['dropdown_options'] = 'Pudotusvalikon asetukset <em>(sovelletaan vain pudotusvalikon kenttiin)</em><br/><br/><em>(yksi kentt&auml; / rivi)</em>';
$lang['edit'] = 'Muokkaa';
$lang['edit_attribset'] = 'Muokkaa attribuuttia';
$lang['edit_attribsets'] = 'Muokkaa attribuutin asetuksia';
$lang['edit_attribsets_for'] = 'Muokkaa attribuutin asetuksia';
$lang['edit_attributes'] = 'Muokkaa attribuutteja';
$lang['edit_category'] = 'Lis&auml;&auml; kategoria';
$lang['edit_category_fields'] = 'Muokkaa kategoria kentti&auml; &quot;%s&quot;:lle';
$lang['edit_hierarchy_item'] = 'Muokkaa hierarkia itemi&auml;';
$lang['errors'] = 'Virheet';
$lang['error_attribset_exists'] = 'Samanniminen attribuutti on jo luotu';
$lang['error_dberror'] = 'Tietokanta virhe';
$lang['error_duplicate_sku'] = 'Dublikaatti SKU arvo l&ouml;ydetty';
$lang['error_fieldvalue_empty'] = 'Kentt&auml; ei voi olla tyhj&auml;';
$lang['error_fileformat'] = 'Tiedostoformaatti-ongelma';
$lang['error_filenotfound'] = 'Tiedostoa ei l&ouml;ydy';
$lang['error_fileopen'] = 'Virhe avattaessa tiedostoa %s';
$lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it&#039;s own parent)';
$lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
$lang['error_invalid_value'] = 'Invalid value specified';
$lang['error_missingparam'] = 'A required parameter is missing or invalid';
$lang['error_nameused'] = 'An item by that name is already in use';
$lang['error_nofieldtype'] = 'Please select a field type';
$lang['error_noname'] = 'You must supply a name';
$lang['error_onequantityfield'] = 'Only one quantity field is allowed';
$lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
$lang['error_permissiondenied'] = 'Permission Denied';
$lang['error_product_aliasused'] = 'The alias specified is already in use';
$lang['error_product_nameused'] = 'An item by that name already exists';
$lang['error_product_notfound'] = 'The requested item could not be found';
$lang['error_product_skuused'] = 'That SKU value is already in use by another item';
$lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
$lang['error_sku_required'] = 'Please enter a unique SKU';
$lang['error_upload_failed'] = 'Upload failed: %s';
$lang['exclude_categories'] = 'Exclude items in the selected categories from the results';
$lang['expire_six_months'] = 'Kuuden kuukauden j&auml;lkeen';
$lang['expire_one_year'] = 'Yhden vuoden j&auml;lkeen';
$lang['expire_two_year'] = 'Kahden vuoden j&auml;lkeen';
$lang['export_to_csv'] = 'Luo CSV';
$lang['exportattribs'] = 'Vie attribuutit';
$lang['exportcats'] = 'Vie kaeoriat';
$lang['exportdelim'] = 'Vie kent&auml;n erottimet';
$lang['exportdraft'] = 'Vie luonnokset';
$lang['exportfields'] = 'Vie kent&auml;t';
$lang['extra1'] = 'Extra-kentt&auml; 1';
$lang['extra2'] = 'Extra-kentt&auml; 2';
$lang['field'] = 'Kentt&auml;';
$lang['fields'] = 'Kent&auml;t';
$lang['fielddef'] = 'Kent&auml;n m&auml;&auml;ritykset';
$lang['fielddefs'] = 'Kenttien m&auml;&auml;ritykset';
$lang['file'] = 'Tiedosto';
$lang['filter'] = 'Filtteri';
$lang['filterinuse'] = 'Voimassa';
$lang['filters'] = 'Filtterit';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Yleiset asetukset';
$lang['go'] = 'Mene';
$lang['hierarchy'] = 'Hierarkia';
$lang['hierarchy_position'] = 'Hierarkian sijainti';
$lang['hierarchy_settings'] = 'Hierarkian asetukset';
$lang['id'] = 'Id';
$lang['imagetext'] = 'Kuva';
$lang['image_handling_settings'] = 'Kuvan k&auml;sittelyasetukset';
$lang['import_from_csv'] = 'Tuo tuotteet CSV-tiedostosta';
$lang['inches'] = 'Tuumat';
$lang['include_children'] = 'Include Children?';
$lang['info_alnumonly'] = 'Only alphanumeric characters. No whitespace, quotes, or non letter/number combinations';
$lang['info_attribtemplate'] = 'Possible variables are: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_attributes_copied'] = 'Attribuutti kopioitu';
$lang['info_autowatermark'] = 'Watermark settings are taken from the CGExtensions Module';
$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
$lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the item detail and summary displays';
$lang['info_copy_attribsets'] = 'This action will copy Attribute Sets (excluding sku values) from another item.';
$lang['info_clearattribs'] = 'Only applicable when updating existing items, this will clear all attribute information from the database for items before creating new ones';
$lang['info_clearcategories'] = 'Only applicable when updating existing items, this will clear all category memberships befoe creating new ones';
$lang['info_clearfields'] = 'Only applicable when updating existing items, this will clear all fields befoe creating field values';
$lang['info_createfields'] = 'Create unknown item fields automatically? <em>(They will be created as text fields)</em>';
$lang['info_createcategories'] = 'Automatically create item categories to match those of the CSV file, if it does not already exist';
$lang['info_createhierarchy'] = 'Automatically create item hierarchies to match those of the CSV file if it does not already exist';
$lang['info_decimal_units'] = 'This system understands (.) as the decimal point separator. i.e.: <strong>5.25</strong>';
$lang['info_delimiter'] = 'Specify the character (or characters) that seperate each field';
$lang['info_duplicateproducts'] = 'Specify how the system should handle an item whos name already exists in the CSV file';
$lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all items.';
$lang['info_fieldproblems'] = 'Problems were encountered when dealing with one or more custom fields.  The action has completed successfully, however you should investigate and correct these problems';
$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
$lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
$lang['info_imagestuff_deprecated'] = 'Image processing functions are deprecated and will be removed in a future version.  Use CGSmartImage for inline image processing.';
$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
$lang['info_price_adjustment'] = 'Valid values are +-*#.##';
$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if an item detail view is accessed directly by URL, and that item for whatever reason (disabled, deleted, etc) cannot be accessed.';
$lang['info_publicfield'] = 'Public fields are available for the public to see';
$lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjust the order that they will be displayed in in the hierarchy view';
$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the items module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
$lang['label'] = 'Otsikko';
$lang['label_skip'] = 'Ohita';
$lang['label_overwrite'] = 'Ylikirjoita';
$lang['label_update'] = 'P&auml;iv&auml;t&auml;';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Viimeeksi muokattu';
$lang['logotext'] = 'Toinen kuva';
$lang['maxlength'] = 'Maximum length <em>(applicable only on textbox fields)</em>';
$lang['modifieddate'] = 'Muokkausp&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['module_description'] = 'A module for managing a catalog of items, their price, images, etc, and for allowing users to build a cart';
$lang['move_down'] = 'Siirr&auml; alas';
$lang['move_up'] = 'Siirr&auml; yl&ouml;s';
$lang['msg_eventhandlers_created'] = 'Event Handlers Created';
$lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
$lang['name'] = 'Nimi';
$lang['needpermission'] = 'Sinulla ei ole tarvittavia oikeuksia: %s';
$lang['new_category_name'] = 'Uusi kategorian nimi';
$lang['nextpage'] = '>';
$lang['no'] = 'Ei';
$lang['nonamegiven'] = 'Nime&auml; ei annettu';
$lang['none'] = 'Ei yht&auml;&auml;n';
$lang['nothing_selectd'] = 'Mit&auml;&auml;n ei valittu';
$lang['of'] = 'Of';
$lang['operation_cancelled'] = 'Operaatio peruutettu';
$lang['operation_complete'] = 'Operaatio suoritettu';
$lang['page'] = 'Page';
$lang['page_of'] = 'Sivu %s of %s';
$lang['page_limit'] = 'Sivurajoitus';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display an item list by hierarchy</li>
  <li>categorylist - Display a list of item categories</li>
  <li><em>default</em> - Display a summary of items</li>
  <li>details - Display a detail view of a single item</li>
  <li>fieldlist - Display a list of values from a specified field.
     <p>
&nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &quot;color&quot; and then create a navigation based on the different colors.
     </p>
  </li>
  <li>search - Display a form to allow searching items on various criterium</li>
<li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
</ul>';
$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories.';
$lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
$lang['param_categorylisttemplate'] = 'Useful only with the categorylist and fieldlist actions, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort.';
$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled.';
$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding items that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the items that are in this category, but not in that category';
$lang['param_field'] = 'Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively.';
$lang['param_fieldval'] = 'Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &quot;::null::&quot; &quot;::notnull::&quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
$lang['param_hierarchy'] = 'Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
$lang['param_pagelimit'] = 'Useful only with the <em>default</em> or search actions, this parameter specifies how many items should be listed on each page.';
$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
$lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what item to use for the display.';
$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without items) will be displayed.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary (including after a search) view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
<ul>
  <li><strong>item_name</strong></li>
  <li>id -- The item id</li>
  <li>weight -- The item weight</li>
  <li>price -- The item base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
  <li>f:fieldname -- Allows sorting by values of custom fields.</li>
</ul>
<p>The category list view supports only a few specific sorting options:</p>
<ul>
  <li>id -- The category id.</li>
  <li><strong>name</strong> -- The category name.</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
$lang['param_summarytemplate'] = 'This parameter specifies the template that should be used for the summary mode display.  It is also accepted in the search action.  If no value is specified, then the current default template of that type is used.';
$lang['parent'] = 'Parent';
$lang['postinstall'] = 'Products moduuli on onnistuneesti asennettu';
$lang['postuninstall'] = 'The Products module has been removed along with all associated data';
$lang['preferences'] = 'Asetukset';
$lang['preuninstall'] = 'Removing this module will also remove all associated data, are you sure you want to proceed?';
$lang['price'] = 'Hinta';
$lang['price_adjustment'] = 'Price Adjustment';
$lang['prefix_copyof'] = 'Kopio';
$lang['prevpage'] = '<';
$lang['product'] = 'Tuote';
$lang['productname'] = 'Tuotteen nimi';
$lang['products'] = 'Tuoteet';
$lang['product_detail_settings'] = 'Tuoteen asetukset';
$lang['product_editing_settings'] = 'Tuoteen muokkausasetukset';
$lang['product_summary_settings'] = 'Tuotteen kooosteasetukset';
$lang['product_hierarchy'] = 'Tuotehierarkia';
$lang['product_info'] = 'Tuotetiedot';
$lang['product_manager'] = 'Product Manager';
$lang['progress'] = 'Progress';
$lang['prompt'] = 'Prompt';
$lang['prompt_add_attribset'] = 'Add/Edit Attribute Set';
$lang['prompt_allowed_filetypes'] = 'Allow upload of files with these extensions (for all upload fields)';
$lang['prompt_allowed_imagetypes'] = 'Allow processing of images with these extensions (for image type fields)';
$lang['prompt_attribtemplate'] = 'Template for display of item attribute values in dropdown';
$lang['prompt_autothumbnail'] = 'Automatically create thumbnails of images';
$lang['prompt_autothumbnail_size'] = 'Maximum size (largest dimension) of the thumbnail.';
$lang['prompt_autopreviewimg'] = 'Automatically create preview images of images';
$lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
$lang['prompt_autowatermark'] = 'Automatically place watermarks on images';
$lang['prompt_applicable'] = 'Enable by default for all new items';
$lang['prompt_batchsize'] = 'Er&auml;n koko';
$lang['prompt_cart_module'] = 'Cart Module';
$lang['prompt_cart_module_params'] = 'Cart Module Parameters';
$lang['prompt_clearattribs'] = 'Clear attributes on update';
$lang['prompt_clearcategories'] = 'Clear categories on update';
$lang['prompt_clearfields'] = 'Clear fields on update';
$lang['prompt_createcategories'] = 'Create Categories';
$lang['prompt_createfields'] = 'Create Item Fields?';
$lang['prompt_createhierarchy'] = 'Create Item Hierarchy';
$lang['prompt_csvfile'] = 'Tuo CSV tiedosto';
$lang['prompt_currencycode'] = 'Valuuttakoodi';
$lang['prompt_currencysymbol'] = 'Valuutan symboli';
$lang['prompt_default_status'] = 'By default all new items have this status';
$lang['prompt_default_taxable'] = 'By default all new items are taxable';
$lang['prompt_deleteproductfiles'] = 'Delete any files associated with the item when the item is deleted?';
$lang['prompt_delimiter'] = 'Field Delimiter';
$lang['prompt_detailpage'] = 'Default Detail Page';
$lang['prompt_detailsfor'] = 'Details for %s';
$lang['prompt_duplicateproducts'] = 'How to handle duplicate items?';
$lang['prompt_false'] = 'Ep&auml;tosi';
$lang['prompt_handleimages'] = 'Handle images?';
$lang['prompt_imagepath'] = 'Kuvan tiedostopolku';
$lang['prompt_lengthunits'] = 'Length Units';
$lang['prompt_notfound_behavior'] = 'What action should be taken when an item cannot be displayed?';
$lang['prompt_notfound_404'] = 'Generate a 404 error';
$lang['prompt_notfound_301'] = 'Generate a 301 redirect';
$lang['prompt_notfound_errormsg'] = 'Display an error message';
$lang['prompt_notfound_msg'] = 'Error message for when an item cannot be found';
$lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
$lang['prompt_prod_detailpage'] = 'Default Page for Item Detail Views';
$lang['prompt_products_matching'] = 'Items matching %s';
$lang['prompt_sku_required'] = 'SKU is required for all items and attributes';
$lang['prompt_summary_newdefault'] = 'Use new summary view';
$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
$lang['prompt_summarysortorder'] = 'Default Sort Order in summary mode';
$lang['prompt_summarysorting'] = 'Default Sort Field in summary mode';
$lang['prompt_template'] = 'Template Source';
$lang['prompt_true'] = 'Tosi';
$lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
$lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Item Detail URLS';
$lang['prompt_weightunits'] = 'Painon mittayksikk&ouml;';
$lang['public'] = 'Is this a public field?';
$lang['published'] = 'Julkaistu';
$lang['quantity_on_hand'] = 'Quantity on Hand';
$lang['random'] = 'Satunnainen';
$lang['reorder_hierarchy'] = 'J&auml;rjest&auml; hierarkia';
$lang['reset'] = 'Nollata';
$lang['resettofactory'] = 'Palauta tehdasasetukset';
$lang['return'] = 'Palaa';
$lang['return_to_top'] = 'Palaa p&auml;&auml;n&auml;kym&auml;&auml;n';
$lang['root'] = 'Root';
$lang['search_description'] = 'Search Property Description';
$lang['search_expr'] = 'Should the query match all, or any of the tests below?';
$lang['search_name'] = 'Search Property Name';
$lang['search_price'] = 'Hintaraja';
$lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
$lang['searchtemplates'] = 'Search Templates';
$lang['select_all'] = 'Valitse kaikki';
$lang['select_one'] = 'Valitse yksi';
$lang['setdraft'] = 'Aseta luonnokseksi';
$lang['setpublished'] = 'Aseta julkiseksi';
$lang['sku'] = 'SKU';
$lang['sort_by'] = 'J&auml;rjest&auml;';
$lang['sort_order'] = 'Sort Order';
$lang['source'] = 'L&auml;hde';
$lang['status'] = 'Tila';
$lang['submit'] = 'Submit';
$lang['subscription'] = 'Subscription';
$lang['subscr_expiry'] = 'Expiry';
$lang['subscr_expiry2'] = 'Expires';
$lang['subscr_monthly'] = 'Monthly';
$lang['subscr_delperiod'] = 'Delivery Frequency';
$lang['subscr_delperiod2'] = 'Delievered';
$lang['subscr_payperiod'] = 'Payment Frequency';
$lang['subscr_payperiod2'] = 'Maksettu';
$lang['subscr_quarterly'] = 'Quarterly';
$lang['subscr_semianually'] = 'Semi Anually';
$lang['subscr_yearly'] = 'Yearly';
$lang['summarytemplates'] = 'Summary Templates';
$lang['summarytemplate_addedit'] = 'Add/Edit A Summary Template';
$lang['taxable'] = 'Taxable';
$lang['test'] = 'Test';
$lang['textarea'] = 'Text Area';
$lang['textbox'] = 'Text Input';
$lang['title_byhierarchy_dflttemplate'] = 'Default New Hierarchy Report Template';
$lang['title_categorylist_dflttemplate'] = 'Default New CategoryList Template';
$lang['title_detail_dflttemplate'] = 'Default New Detail Template';
$lang['title_search_dflttemplate'] = 'Default New Search Template';
$lang['title_summary_dflttemplate'] = 'Default New Summary Template';
$lang['type'] = 'Type';
$lang['up'] = 'Move Up';
$lang['update'] = 'Update';
$lang['upload'] = 'Select a file to upload';
$lang['url_alias'] = 'URL Alias';
$lang['valid'] = 'Valid';
$lang['value'] = 'Value';
$lang['values'] = 'Values';
$lang['view'] = 'View';
$lang['viewable_fields'] = 'Select custom fields to view in the table';
$lang['watermark_location'] = 'Watermark Location';
$lang['weight'] = 'Weight';
$lang['with_selected'] = 'With Selected';
$lang['yes'] = 'Yes';
$lang['utma'] = '156861353.1066091838.1349285414.1349285414.1349285414.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1349285414.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>